@@ -56,28 +56,27 @@ SENSOR_TYPES: dict[str, BMWSensorEntityDescription] = {
     # --- Generic ---
     "charging_start_time": BMWSensorEntityDescription(
         key="charging_start_time",
+        name="Charging start time",
         key_class="fuel_and_battery",
         device_class=SensorDeviceClass.TIMESTAMP,
         entity_registry_enabled_default=False,
     ),
     "charging_end_time": BMWSensorEntityDescription(
         key="charging_end_time",
+        name="Charging end time",
         key_class="fuel_and_battery",
         device_class=SensorDeviceClass.TIMESTAMP,
     ),
-    "charging_time_label": BMWSensorEntityDescription(
-        key="charging_time_label",
-        key_class="fuel_and_battery",
-        entity_registry_enabled_default=False,
-    ),
     "charging_status": BMWSensorEntityDescription(
         key="charging_status",
+        name="Charging status",
         key_class="fuel_and_battery",
         icon="mdi:ev-station",
         value=lambda x, y: x.value,
     ),
     "remaining_battery_percent": BMWSensorEntityDescription(
         key="remaining_battery_percent",
+        name="Remaining battery percent",
         key_class="fuel_and_battery",
         unit_type=PERCENTAGE,
         device_class=SensorDeviceClass.BATTERY,
@@ -85,12 +84,14 @@ SENSOR_TYPES: dict[str, BMWSensorEntityDescription] = {
     # --- Specific ---
     "mileage": BMWSensorEntityDescription(
         key="mileage",
+        name="Mileage",
         icon="mdi:speedometer",
         unit_type=LENGTH,
         value=lambda x, hass: convert_and_round(x, hass.config.units.length, 2),
     ),
     "remaining_range_total": BMWSensorEntityDescription(
         key="remaining_range_total",
+        name="Remaining range total",
         key_class="fuel_and_battery",
         icon="mdi:map-marker-distance",
         unit_type=LENGTH,
@@ -98,6 +99,7 @@ SENSOR_TYPES: dict[str, BMWSensorEntityDescription] = {
     ),
     "remaining_range_electric": BMWSensorEntityDescription(
         key="remaining_range_electric",
+        name="Remaining range electric",
         key_class="fuel_and_battery",
         icon="mdi:map-marker-distance",
         unit_type=LENGTH,
@@ -105,6 +107,7 @@ SENSOR_TYPES: dict[str, BMWSensorEntityDescription] = {
     ),
     "remaining_range_fuel": BMWSensorEntityDescription(
         key="remaining_range_fuel",
+        name="Remaining range fuel",
         key_class="fuel_and_battery",
         icon="mdi:map-marker-distance",
         unit_type=LENGTH,
@@ -112,6 +115,7 @@ SENSOR_TYPES: dict[str, BMWSensorEntityDescription] = {
     ),
     "remaining_fuel": BMWSensorEntityDescription(
         key="remaining_fuel",
+        name="Remaining fuel",
         key_class="fuel_and_battery",
         icon="mdi:gas-station",
         unit_type=VOLUME,
@@ -119,6 +123,7 @@ SENSOR_TYPES: dict[str, BMWSensorEntityDescription] = {
     ),
     "remaining_fuel_percent": BMWSensorEntityDescription(
         key="remaining_fuel_percent",
+        name="Remaining fuel percent",
         key_class="fuel_and_battery",
         icon="mdi:gas-station",
         unit_type=PERCENTAGE,
@@ -164,8 +169,6 @@ class BMWSensor(BMWBaseEntity, SensorEntity):
         """Initialize BMW vehicle sensor."""
         super().__init__(coordinator, vehicle)
         self.entity_description = description
-
-        self._attr_name = f"{vehicle.name} {description.key}"
         self._attr_unique_id = f"{vehicle.vin}-{description.key}"
 
         # Set the correct unit of measurement based on the unit_type
