@@ -81,11 +81,10 @@ async def async_setup_entry(
     )
 
 
-class DeconzNumber(DeconzDevice, NumberEntity):
+class DeconzNumber(DeconzDevice[Presence], NumberEntity):
     """Representation of a deCONZ number entity."""
 
     TYPE = DOMAIN
-    _device: Presence
 
     def __init__(
         self,
@@ -95,17 +94,10 @@ class DeconzNumber(DeconzDevice, NumberEntity):
     ) -> None:
         """Initialize deCONZ number entity."""
         self.entity_description: DeconzNumberDescription = description
+        self._update_key = self.entity_description.update_key
+        self._name_suffix = description.suffix
         super().__init__(device, gateway)
 
-        self._attr_name = f"{device.name} {description.suffix}"
-        self._update_keys = {self.entity_description.update_key, "reachable"}
-
-    @callback
-    def async_update_callback(self) -> None:
-        """Update the number value."""
-        if self._device.changed_keys.intersection(self._update_keys):
-            super().async_update_callback()
-
     @property
     def native_value(self) -> float | None:
         """Return the value of the sensor property."""
