@@ -1,8 +1,6 @@
 """Support for sensors."""
 from __future__ import annotations
 
-from fjaraskupan import Device
-
 from homeassistant.components.number import NumberEntity
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import TIME_MINUTES
@@ -23,9 +21,7 @@ async def async_setup_entry(
 
     def _constructor(coordinator: Coordinator) -> list[Entity]:
         return [
-            PeriodicVentingTime(
-                coordinator, coordinator.device, coordinator.device_info
-            ),
+            PeriodicVentingTime(coordinator, coordinator.device_info),
         ]
 
     async_setup_entry_platform(hass, config_entry, async_add_entities, _constructor)
@@ -45,13 +41,11 @@ class PeriodicVentingTime(CoordinatorEntity[Coordinator], NumberEntity):
     def __init__(
         self,
         coordinator: Coordinator,
-        device: Device,
         device_info: DeviceInfo,
     ) -> None:
         """Init number entities."""
         super().__init__(coordinator)
-        self._device = device
-        self._attr_unique_id = f"{device.address}-periodic-venting"
+        self._attr_unique_id = f"{coordinator.device.address}-periodic-venting"
         self._attr_device_info = device_info
         self._attr_name = "Periodic venting"
 
@@ -64,5 +58,5 @@ class PeriodicVentingTime(CoordinatorEntity[Coordinator], NumberEntity):
 
     async def async_set_native_value(self, value: float) -> None:
         """Set new value."""
-        await self._device.send_periodic_venting(int(value))
-        self.coordinator.async_set_updated_data(self._device.state)
+        async with self.coordinator.async_connect_and_update() as device:
+            await device.send_periodic_venting(int(value))
