@@ -22,9 +22,15 @@ from homeassistant.const import (
 )
 from homeassistant.core import HassJob, HomeAssistant, ServiceCall, callback
 from homeassistant.exceptions import TemplateError, Unauthorized
-from homeassistant.helpers import config_validation as cv, event, template
+from homeassistant.helpers import (
+    config_validation as cv,
+    discovery_flow,
+    event,
+    template,
+)
 from homeassistant.helpers.device_registry import DeviceEntry
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
+from homeassistant.helpers.entity_platform import async_get_platforms
 from homeassistant.helpers.reload import (
     async_integration_yaml_config,
     async_reload_integration_platforms,
@@ -60,13 +66,7 @@ from .const import (  # noqa: F401
     CONF_TLS_VERSION,
     CONF_TOPIC,
     CONF_WILL_MESSAGE,
-    CONFIG_ENTRY_IS_SETUP,
     DATA_MQTT,
-    DATA_MQTT_CONFIG,
-    DATA_MQTT_RELOAD_DISPATCHERS,
-    DATA_MQTT_RELOAD_ENTRY,
-    DATA_MQTT_RELOAD_NEEDED,
-    DATA_MQTT_UPDATED_CONFIG,
     DEFAULT_ENCODING,
     DEFAULT_QOS,
     DEFAULT_RETAIN,
@@ -76,7 +76,7 @@ from .const import (  # noqa: F401
     PLATFORMS,
     RELOADABLE_PLATFORMS,
 )
-from .mixins import async_discover_yaml_entities
+from .mixins import MqttData
 from .models import (  # noqa: F401
     MqttCommandTemplate,
     MqttValueTemplate,
@@ -164,6 +164,8 @@ async def _async_setup_discovery(
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Start the MQTT protocol service."""
+    mqtt_data: MqttData = hass.data.setdefault(DATA_MQTT, MqttData())
+
     conf: ConfigType | None = config.get(DOMAIN)
 
     websocket_api.async_register_command(hass, websocket_subscribe)
@@ -172,25 +174,24 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
 
     if conf:
         conf = dict(conf)
-        hass.data[DATA_MQTT_CONFIG] = conf
+        mqtt_data.config = conf
 
     if (mqtt_entry_status := mqtt_config_entry_enabled(hass)) is None:
         # Create an import flow if the user has yaml configured entities etc.
         # but no broker configuration. Note: The intention is not for this to
         # import broker configuration from YAML because that has been deprecated.
-        hass.async_create_task(
-            hass.config_entries.flow.async_init(
-                DOMAIN,
-                context={"source": config_entries.SOURCE_INTEGRATION_DISCOVERY},
-                data={},
-            )
+        discovery_flow.async_create_flow(
+            hass,
+            DOMAIN,
+            context={"source": config_entries.SOURCE_INTEGRATION_DISCOVERY},
+            data={},
         )
-        hass.data[DATA_MQTT_RELOAD_NEEDED] = True
+        mqtt_data.reload_needed = True
     elif mqtt_entry_status is False:
         _LOGGER.info(
             "MQTT will be not available until the config entry is enabled",
         )
-        hass.data[DATA_MQTT_RELOAD_NEEDED] = True
+        mqtt_data.reload_needed = True
 
     return True
 
@@ -248,33 +249,34 @@ async def _async_config_entry_updated(hass: HomeAssistant, entry: ConfigEntry) -
 
     Causes for this is config entry options changing.
     """
-    mqtt_client = hass.data[DATA_MQTT]
+    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    assert (client := mqtt_data.client) is not None
 
-    if (conf := hass.data.get(DATA_MQTT_CONFIG)) is None:
+    if (conf := mqtt_data.config) is None:
         conf = CONFIG_SCHEMA_BASE(dict(entry.data))
 
-    mqtt_client.conf = _merge_extended_config(entry, conf)
-    await mqtt_client.async_disconnect()
-    mqtt_client.init_client()
-    await mqtt_client.async_connect()
+    mqtt_data.config = _merge_extended_config(entry, conf)
+    await client.async_disconnect()
+    client.init_client()
+    await client.async_connect()
 
     await discovery.async_stop(hass)
-    if mqtt_client.conf.get(CONF_DISCOVERY):
-        await _async_setup_discovery(hass, mqtt_client.conf, entry)
+    if client.conf.get(CONF_DISCOVERY):
+        await _async_setup_discovery(hass, cast(ConfigType, mqtt_data.config), entry)
 
 
 async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict | None:
     """Fetch fresh MQTT yaml config from the hass config when (re)loading the entry."""
-    if DATA_MQTT_RELOAD_ENTRY in hass.data:
+    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    if mqtt_data.reload_entry:
         hass_config = await conf_util.async_hass_config_yaml(hass)
-        mqtt_config = CONFIG_SCHEMA_BASE(hass_config.get(DOMAIN, {}))
-        hass.data[DATA_MQTT_CONFIG] = mqtt_config
+        mqtt_data.config = CONFIG_SCHEMA_BASE(hass_config.get(DOMAIN, {}))
 
     # Remove unknown keys from config entry data
     _filter_entry_config(hass, entry)
 
     # Merge basic configuration, and add missing defaults for basic options
-    _merge_basic_config(hass, entry, hass.data.get(DATA_MQTT_CONFIG, {}))
+    _merge_basic_config(hass, entry, mqtt_data.config or {})
     # Bail out if broker setting is missing
     if CONF_BROKER not in entry.data:
         _LOGGER.error("MQTT broker is not configured, please configure it")
@@ -282,7 +284,7 @@ async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict |
 
     # If user doesn't have configuration.yaml config, generate default values
     # for options not in config entry data
-    if (conf := hass.data.get(DATA_MQTT_CONFIG)) is None:
+    if (conf := mqtt_data.config) is None:
         conf = CONFIG_SCHEMA_BASE(dict(entry.data))
 
     # User has configuration.yaml config, warn about config entry overrides
@@ -305,15 +307,20 @@ async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict |
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Load a config entry."""
+    mqtt_data: MqttData = hass.data.setdefault(DATA_MQTT, MqttData())
+
     # Merge basic configuration, and add missing defaults for basic options
     if (conf := await async_fetch_config(hass, entry)) is None:
         # Bail out
         return False
-
-    hass.data[DATA_MQTT] = MQTT(hass, entry, conf)
+    mqtt_data.client = MQTT(hass, entry, conf)
+    # Restore saved subscriptions
+    if mqtt_data.subscriptions_to_restore:
+        mqtt_data.client.subscriptions = mqtt_data.subscriptions_to_restore
+        mqtt_data.subscriptions_to_restore = []
     entry.add_update_listener(_async_config_entry_updated)
 
-    await hass.data[DATA_MQTT].async_connect()
+    await mqtt_data.client.async_connect()
 
     async def async_publish_service(call: ServiceCall) -> None:
         """Handle MQTT publish service calls."""
@@ -362,7 +369,8 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
                 )
                 return
 
-        await hass.data[DATA_MQTT].async_publish(msg_topic, payload, qos, retain)
+        assert mqtt_data.client is not None and msg_topic is not None
+        await mqtt_data.client.async_publish(msg_topic, payload, qos, retain)
 
     hass.services.async_register(
         DOMAIN, SERVICE_PUBLISH, async_publish_service, schema=MQTT_PUBLISH_SCHEMA
@@ -403,7 +411,6 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     )
 
     # setup platforms and discovery
-    hass.data[CONFIG_ENTRY_IS_SETUP] = set()
 
     async def async_setup_reload_service() -> None:
         """Create the reload service for the MQTT domain."""
@@ -416,13 +423,25 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
             await async_reload_integration_platforms(hass, DOMAIN, RELOADABLE_PLATFORMS)
 
             # Reload the modern yaml platforms
+            mqtt_platforms = async_get_platforms(hass, DOMAIN)
+            tasks = [
+                entity.async_remove()
+                for mqtt_platform in mqtt_platforms
+                for entity in mqtt_platform.entities.values()
+                if not entity._discovery_data  # type: ignore[attr-defined] # pylint: disable=protected-access
+                if mqtt_platform.config_entry
+                and mqtt_platform.domain in RELOADABLE_PLATFORMS
+            ]
+            await asyncio.gather(*tasks)
+
             config_yaml = await async_integration_yaml_config(hass, DOMAIN) or {}
-            hass.data[DATA_MQTT_UPDATED_CONFIG] = config_yaml.get(DOMAIN, {})
+            mqtt_data.updated_config = config_yaml.get(DOMAIN, {})
             await asyncio.gather(
                 *(
                     [
-                        async_discover_yaml_entities(hass, component)
+                        mqtt_data.reload_handlers[component]()
                         for component in RELOADABLE_PLATFORMS
+                        if component in mqtt_data.reload_handlers
                     ]
                 )
             )
@@ -434,6 +453,7 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     async def async_forward_entry_setup_and_setup_discovery(config_entry):
         """Forward the config entry setup to the platforms and set up discovery."""
+        reload_manual_setup: bool = False
         # Local import to avoid circular dependencies
         # pylint: disable-next=import-outside-toplevel
         from . import device_automation, tag
@@ -456,8 +476,17 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
             await _async_setup_discovery(hass, conf, entry)
         # Setup reload service after all platforms have loaded
         await async_setup_reload_service()
-        if DATA_MQTT_RELOAD_NEEDED in hass.data:
-            hass.data.pop(DATA_MQTT_RELOAD_NEEDED)
+        # When the entry is reloaded, also reload manual set up items to enable MQTT
+        if mqtt_data.reload_entry:
+            mqtt_data.reload_entry = False
+            reload_manual_setup = True
+
+        # When the entry was disabled before, reload manual set up items to enable MQTT again
+        if mqtt_data.reload_needed:
+            mqtt_data.reload_needed = False
+            reload_manual_setup = True
+
+        if reload_manual_setup:
             await async_reload_manual_mqtt_items(hass)
 
     await async_forward_entry_setup_and_setup_discovery(entry)
@@ -564,7 +593,9 @@ def async_subscribe_connection_status(
 
 def is_connected(hass: HomeAssistant) -> bool:
     """Return if MQTT client is connected."""
-    return hass.data[DATA_MQTT].connected
+    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    assert mqtt_data.client is not None
+    return mqtt_data.client.connected
 
 
 async def async_remove_config_entry_device(
@@ -580,6 +611,10 @@ async def async_remove_config_entry_device(
 
 async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload MQTT dump and publish service when the config entry is unloaded."""
+    mqtt_data: MqttData = hass.data[DATA_MQTT]
+    assert mqtt_data.client is not None
+    mqtt_client = mqtt_data.client
+
     # Unload publish and dump services.
     hass.services.async_remove(
         DOMAIN,
@@ -592,7 +627,6 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     # Stop the discovery
     await discovery.async_stop(hass)
-    mqtt_client: MQTT = hass.data[DATA_MQTT]
     # Unload the platforms
     await asyncio.gather(
         *(
@@ -602,23 +636,30 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     )
     await hass.async_block_till_done()
     # Unsubscribe reload dispatchers
-    while reload_dispatchers := hass.data.setdefault(DATA_MQTT_RELOAD_DISPATCHERS, []):
+    while reload_dispatchers := mqtt_data.reload_dispatchers:
         reload_dispatchers.pop()()
-    hass.data[CONFIG_ENTRY_IS_SETUP] = set()
     # Cleanup listeners
     mqtt_client.cleanup()
 
     # Trigger reload manual MQTT items at entry setup
-    # Reload the legacy yaml platform
-    await async_reload_integration_platforms(hass, DOMAIN, RELOADABLE_PLATFORMS)
     if (mqtt_entry_status := mqtt_config_entry_enabled(hass)) is False:
         # The entry is disabled reload legacy manual items when the entry is enabled again
-        hass.data[DATA_MQTT_RELOAD_NEEDED] = True
+        mqtt_data.reload_needed = True
     elif mqtt_entry_status is True:
         # The entry is reloaded:
         # Trigger re-fetching the yaml config at entry setup
-        hass.data[DATA_MQTT_RELOAD_ENTRY] = True
-    # Stop the loop
+        mqtt_data.reload_entry = True
+    # Reload the legacy yaml platform to make entities unavailable
+    await async_reload_integration_platforms(hass, DOMAIN, RELOADABLE_PLATFORMS)
+    # Cleanup entity registry hooks
+    registry_hooks = mqtt_data.discovery_registry_hooks
+    while registry_hooks:
+        registry_hooks.popitem()[1]()
+    # Wait for all ACKs and stop the loop
     await mqtt_client.async_disconnect()
+    # Store remaining subscriptions to be able to restore or reload them
+    # when the entry is set up again
+    if mqtt_client.subscriptions:
+        mqtt_data.subscriptions_to_restore = mqtt_client.subscriptions
 
     return True
