@@ -12,6 +12,7 @@ from homeassistant.components.sensor import (
     SensorDeviceClass,
     SensorEntity,
     SensorEntityDescription,
+    SensorStateClass,
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
@@ -29,8 +30,10 @@ from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 from .const import (
     DOMAIN,
     KEY_COORDINATOR,
+    KEY_COORDINATOR_LINK,
     KEY_COORDINATOR_SPEED,
     KEY_COORDINATOR_TRAFFIC,
+    KEY_COORDINATOR_UTIL,
     KEY_ROUTER,
 )
 from .router import NetgearDeviceEntity, NetgearRouter, NetgearRouterEntity
@@ -244,6 +247,34 @@ SENSOR_SPEED_TYPES = [
     ),
 ]
 
+SENSOR_UTILIZATION = [
+    NetgearSensorEntityDescription(
+        key="NewCPUUtilization",
+        name="CPU Utilization",
+        entity_category=EntityCategory.DIAGNOSTIC,
+        native_unit_of_measurement=PERCENTAGE,
+        icon="mdi:cpu-64-bit",
+        state_class=SensorStateClass.MEASUREMENT,
+    ),
+    NetgearSensorEntityDescription(
+        key="NewMemoryUtilization",
+        name="Memory Utilization",
+        entity_category=EntityCategory.DIAGNOSTIC,
+        native_unit_of_measurement=PERCENTAGE,
+        icon="mdi:memory",
+        state_class=SensorStateClass.MEASUREMENT,
+    ),
+]
+
+SENSOR_LINK_TYPES = [
+    NetgearSensorEntityDescription(
+        key="NewEthernetLinkStatus",
+        name="Ethernet Link Status",
+        entity_category=EntityCategory.DIAGNOSTIC,
+        icon="mdi:ethernet",
+    ),
+]
+
 
 async def async_setup_entry(
     hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback
@@ -253,6 +284,8 @@ async def async_setup_entry(
     coordinator = hass.data[DOMAIN][entry.entry_id][KEY_COORDINATOR]
     coordinator_traffic = hass.data[DOMAIN][entry.entry_id][KEY_COORDINATOR_TRAFFIC]
     coordinator_speed = hass.data[DOMAIN][entry.entry_id][KEY_COORDINATOR_SPEED]
+    coordinator_utilization = hass.data[DOMAIN][entry.entry_id][KEY_COORDINATOR_UTIL]
+    coordinator_link = hass.data[DOMAIN][entry.entry_id][KEY_COORDINATOR_LINK]
 
     # Router entities
     router_entities = []
@@ -267,6 +300,16 @@ async def async_setup_entry(
             NetgearRouterSensorEntity(coordinator_speed, router, description)
         )
 
+    for description in SENSOR_UTILIZATION:
+        router_entities.append(
+            NetgearRouterSensorEntity(coordinator_utilization, router, description)
+        )
+
+    for description in SENSOR_LINK_TYPES:
+        router_entities.append(
+            NetgearRouterSensorEntity(coordinator_link, router, description)
+        )
+
     async_add_entities(router_entities)
 
     # Entities per network device
