@@ -10,16 +10,17 @@ from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
-from . import RainMachineEntity
+from . import RainMachineData, RainMachineEntity
 from .const import (
-    DATA_CONTROLLER,
-    DATA_COORDINATOR,
     DATA_PROVISION_SETTINGS,
     DATA_RESTRICTIONS_CURRENT,
     DATA_RESTRICTIONS_UNIVERSAL,
     DOMAIN,
 )
-from .model import RainMachineDescriptionMixinApiCategory
+from .model import (
+    RainMachineEntityDescription,
+    RainMachineEntityDescriptionMixinDataKey,
+)
 from .util import key_exists
 
 TYPE_FLOW_SENSOR = "flow_sensor"
@@ -35,7 +36,9 @@ TYPE_WEEKDAY = "weekday"
 
 @dataclass
 class RainMachineBinarySensorDescription(
-    BinarySensorEntityDescription, RainMachineDescriptionMixinApiCategory
+    BinarySensorEntityDescription,
+    RainMachineEntityDescription,
+    RainMachineEntityDescriptionMixinDataKey,
 ):
     """Describe a RainMachine binary sensor."""
 
@@ -120,8 +123,7 @@ async def async_setup_entry(
     hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback
 ) -> None:
     """Set up RainMachine binary sensors based on a config entry."""
-    controller = hass.data[DOMAIN][entry.entry_id][DATA_CONTROLLER]
-    coordinators = hass.data[DOMAIN][entry.entry_id][DATA_COORDINATOR]
+    data: RainMachineData = hass.data[DOMAIN][entry.entry_id]
 
     api_category_sensor_map = {
         DATA_PROVISION_SETTINGS: ProvisionSettingsBinarySensor,
@@ -131,12 +133,10 @@ async def async_setup_entry(
 
     async_add_entities(
         [
-            api_category_sensor_map[description.api_category](
-                entry, coordinator, controller, description
-            )
+            api_category_sensor_map[description.api_category](entry, data, description)
             for description in BINARY_SENSOR_DESCRIPTIONS
             if (
-                (coordinator := coordinators[description.api_category]) is not None
+                (coordinator := data.coordinators[description.api_category]) is not None
                 and coordinator.data
                 and key_exists(coordinator.data, description.data_key)
             )
@@ -147,6 +147,8 @@ async def async_setup_entry(
 class CurrentRestrictionsBinarySensor(RainMachineEntity, BinarySensorEntity):
     """Define a binary sensor that handles current restrictions data."""
 
+    entity_description: RainMachineBinarySensorDescription
+
     @callback
     def update_from_latest_data(self) -> None:
         """Update the state."""
@@ -167,16 +169,22 @@ class CurrentRestrictionsBinarySensor(RainMachineEntity, BinarySensorEntity):
 class ProvisionSettingsBinarySensor(RainMachineEntity, BinarySensorEntity):
     """Define a binary sensor that handles provisioning data."""
 
+    entity_description: RainMachineBinarySensorDescription
+
     @callback
     def update_from_latest_data(self) -> None:
         """Update the state."""
         if self.entity_description.key == TYPE_FLOW_SENSOR:
-            self._attr_is_on = self.coordinator.data["system"].get("useFlowSensor")
+            self._attr_is_on = self.coordinator.data.get("system", {}).get(
+                "useFlowSensor"
+            )
 
 
 class UniversalRestrictionsBinarySensor(RainMachineEntity, BinarySensorEntity):
     """Define a binary sensor that handles universal restrictions data."""
 
+    entity_description: RainMachineBinarySensorDescription
+
     @callback
     def update_from_latest_data(self) -> None:
         """Update the state."""
