@@ -9,7 +9,7 @@ from functools import cached_property
 import logging
 import random
 import time
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, TypeVar
 
 from zigpy import types
 import zigpy.device
@@ -30,6 +30,7 @@ from homeassistant.helpers.event import async_track_time_interval
 
 from . import channels
 from .const import (
+    ATTR_ACTIVE_COORDINATOR,
     ATTR_ARGS,
     ATTR_ATTRIBUTE,
     ATTR_AVAILABLE,
@@ -85,6 +86,8 @@ _LOGGER = logging.getLogger(__name__)
 _UPDATE_ALIVE_INTERVAL = (60, 90)
 _CHECKIN_GRACE_PERIODS = 2
 
+_ZHADeviceSelfT = TypeVar("_ZHADeviceSelfT", bound="ZHADevice")
+
 
 class DeviceStatus(Enum):
     """Status of a device."""
@@ -252,12 +255,20 @@ class ZHADevice(LogMixin):
 
     @property
     def is_coordinator(self) -> bool | None:
-        """Return true if this device represents the coordinator."""
+        """Return true if this device represents a coordinator."""
         if self._zigpy_device.node_desc is None:
             return None
 
         return self._zigpy_device.node_desc.is_coordinator
 
+    @property
+    def is_active_coordinator(self) -> bool:
+        """Return true if this device is the active coordinator."""
+        if not self.is_coordinator:
+            return False
+
+        return self.ieee == self.gateway.coordinator_ieee
+
     @property
     def is_end_device(self) -> bool | None:
         """Return true if this device is an end device."""
@@ -331,12 +342,12 @@ class ZHADevice(LogMixin):
 
     @classmethod
     def new(
-        cls,
+        cls: type[_ZHADeviceSelfT],
         hass: HomeAssistant,
         zigpy_dev: zigpy.device.Device,
         gateway: ZHAGateway,
         restored: bool = False,
-    ):
+    ) -> _ZHADeviceSelfT:
         """Create new device."""
         zha_dev = cls(hass, zigpy_dev, gateway)
         zha_dev.channels = channels.Channels.new(zha_dev)
@@ -470,8 +481,6 @@ class ZHADevice(LogMixin):
         self.debug("started configuration")
         await self._channels.async_configure()
         self.debug("completed configuration")
-        entry = self.gateway.zha_storage.async_create_or_update_device(self)
-        self.debug("stored in registry: %s", entry)
 
         if (
             should_identify
@@ -496,17 +505,12 @@ class ZHADevice(LogMixin):
         for unsubscribe in self.unsubs:
             unsubscribe()
 
-    @callback
-    def async_update_last_seen(self, last_seen: float | None) -> None:
-        """Set last seen on the zigpy device."""
-        if self._zigpy_device.last_seen is None and last_seen is not None:
-            self._zigpy_device.last_seen = last_seen
-
     @property
     def zha_device_info(self) -> dict[str, Any]:
         """Get ZHA device information."""
         device_info: dict[str, Any] = {}
         device_info.update(self.device_info)
+        device_info[ATTR_ACTIVE_COORDINATOR] = self.is_active_coordinator
         device_info["entities"] = [
             {
                 "entity_id": entity_ref.reference_id,
