@@ -12,7 +12,7 @@ from __future__ import annotations
 from collections import UserDict
 from collections.abc import Callable, Iterable, Mapping
 import logging
-from typing import TYPE_CHECKING, Any, cast
+from typing import TYPE_CHECKING, Any, TypeVar, cast
 
 import attr
 import voluptuous as vol
@@ -30,6 +30,7 @@ from homeassistant.const import (
     MAX_LENGTH_STATE_ENTITY_ID,
     STATE_UNAVAILABLE,
     STATE_UNKNOWN,
+    Platform,
 )
 from homeassistant.core import (
     Event,
@@ -53,6 +54,8 @@ if TYPE_CHECKING:
 
     from .entity import EntityCategory
 
+T = TypeVar("T")
+
 PATH_REGISTRY = "entity_registry.yaml"
 DATA_REGISTRY = "entity_registry"
 EVENT_ENTITY_REGISTRY_UPDATED = "entity_registry_updated"
@@ -60,7 +63,7 @@ SAVE_DELAY = 10
 _LOGGER = logging.getLogger(__name__)
 
 STORAGE_VERSION_MAJOR = 1
-STORAGE_VERSION_MINOR = 7
+STORAGE_VERSION_MINOR = 8
 STORAGE_KEY = "core.entity_registry"
 
 # Attributes relevant to describing entity
@@ -324,41 +327,43 @@ class EntityRegistry:
         disabled_by: RegistryEntryDisabler | None = None,
         hidden_by: RegistryEntryHider | None = None,
         # Data that we want entry to have
-        area_id: str | None = None,
-        capabilities: Mapping[str, Any] | None = None,
-        config_entry: ConfigEntry | None = None,
-        device_id: str | None = None,
-        entity_category: EntityCategory | None = None,
-        has_entity_name: bool | None = None,
-        original_device_class: str | None = None,
-        original_icon: str | None = None,
-        original_name: str | None = None,
-        supported_features: int | None = None,
-        unit_of_measurement: str | None = None,
+        area_id: str | None | UndefinedType = UNDEFINED,
+        capabilities: Mapping[str, Any] | None | UndefinedType = UNDEFINED,
+        config_entry: ConfigEntry | None | UndefinedType = UNDEFINED,
+        device_id: str | None | UndefinedType = UNDEFINED,
+        entity_category: EntityCategory | UndefinedType | None = UNDEFINED,
+        has_entity_name: bool | UndefinedType = UNDEFINED,
+        original_device_class: str | None | UndefinedType = UNDEFINED,
+        original_icon: str | None | UndefinedType = UNDEFINED,
+        original_name: str | None | UndefinedType = UNDEFINED,
+        supported_features: int | None | UndefinedType = UNDEFINED,
+        unit_of_measurement: str | None | UndefinedType = UNDEFINED,
     ) -> RegistryEntry:
         """Get entity. Create if it doesn't exist."""
-        config_entry_id = None
-        if config_entry:
+        config_entry_id: str | None | UndefinedType = UNDEFINED
+        if not config_entry:
+            config_entry_id = None
+        elif config_entry is not UNDEFINED:
             config_entry_id = config_entry.entry_id
 
+        supported_features = supported_features or 0
+
         entity_id = self.async_get_entity_id(domain, platform, unique_id)
 
         if entity_id:
             return self.async_update_entity(
                 entity_id,
-                area_id=area_id or UNDEFINED,
-                capabilities=capabilities or UNDEFINED,
-                config_entry_id=config_entry_id or UNDEFINED,
-                device_id=device_id or UNDEFINED,
-                entity_category=entity_category or UNDEFINED,
-                has_entity_name=has_entity_name
-                if has_entity_name is not None
-                else UNDEFINED,
-                original_device_class=original_device_class or UNDEFINED,
-                original_icon=original_icon or UNDEFINED,
-                original_name=original_name or UNDEFINED,
-                supported_features=supported_features or UNDEFINED,
-                unit_of_measurement=unit_of_measurement or UNDEFINED,
+                area_id=area_id,
+                capabilities=capabilities,
+                config_entry_id=config_entry_id,
+                device_id=device_id,
+                entity_category=entity_category,
+                has_entity_name=has_entity_name,
+                original_device_class=original_device_class,
+                original_icon=original_icon,
+                original_name=original_name,
+                supported_features=supported_features,
+                unit_of_measurement=unit_of_measurement,
                 # When we changed our slugify algorithm, we invalidated some
                 # stored entity IDs with either a __ or ending in _.
                 # Fix introduced in 0.86 (Jan 23, 2019). Next line can be
@@ -380,32 +385,41 @@ class EntityRegistry:
         if (
             disabled_by is None
             and config_entry
+            and config_entry is not UNDEFINED
             and config_entry.pref_disable_new_entities
         ):
             disabled_by = RegistryEntryDisabler.INTEGRATION
 
         from .entity import EntityCategory  # pylint: disable=import-outside-toplevel
 
-        if entity_category and not isinstance(entity_category, EntityCategory):
+        if (
+            entity_category
+            and entity_category is not UNDEFINED
+            and not isinstance(entity_category, EntityCategory)
+        ):
             raise ValueError("entity_category must be a valid EntityCategory instance")
 
+        def none_if_undefined(value: T | UndefinedType) -> T | None:
+            """Return None if value is UNDEFINED, otherwise return value."""
+            return None if value is UNDEFINED else value
+
         entry = RegistryEntry(
-            area_id=area_id,
-            capabilities=capabilities,
-            config_entry_id=config_entry_id,
-            device_id=device_id,
+            area_id=none_if_undefined(area_id),
+            capabilities=none_if_undefined(capabilities),
+            config_entry_id=none_if_undefined(config_entry_id),
+            device_id=none_if_undefined(device_id),
             disabled_by=disabled_by,
-            entity_category=entity_category,
+            entity_category=none_if_undefined(entity_category),
             entity_id=entity_id,
             hidden_by=hidden_by,
-            has_entity_name=has_entity_name or False,
-            original_device_class=original_device_class,
-            original_icon=original_icon,
-            original_name=original_name,
+            has_entity_name=none_if_undefined(has_entity_name) or False,
+            original_device_class=none_if_undefined(original_device_class),
+            original_icon=none_if_undefined(original_icon),
+            original_name=none_if_undefined(original_name),
             platform=platform,
-            supported_features=supported_features or 0,
+            supported_features=none_if_undefined(supported_features) or 0,
             unique_id=unique_id,
-            unit_of_measurement=unit_of_measurement,
+            unit_of_measurement=none_if_undefined(unit_of_measurement),
         )
         self.entities[entity_id] = entry
         _LOGGER.info("Registered new %s.%s entity: %s", domain, platform, entity_id)
@@ -957,10 +971,19 @@ async def _async_migrate(
             entity["hidden_by"] = None
 
     if old_major_version == 1 and old_minor_version < 7:
-        # Version 1.6 adds has_entity_name
+        # Version 1.7 adds has_entity_name
         for entity in data["entities"]:
             entity["has_entity_name"] = False
 
+    if old_major_version == 1 and old_minor_version < 8:
+        # Cleanup after frontend bug which incorrectly updated device_class
+        # Fixed by frontend PR #13551
+        for entity in data["entities"]:
+            domain = split_entity_id(entity["entity_id"])[0]
+            if domain in [Platform.BINARY_SENSOR, Platform.COVER]:
+                continue
+            entity["device_class"] = None
+
     if old_major_version > 1:
         raise NotImplementedError
     return data
